using System;
using System.Collections.Generic;
using System.Linq;
using BigCompany.Web.Models.Domain;
using SisoDb;

namespace BigCompany.Web.Services.Persistence
{
	public class DomainRepository : IDomainRepository
	{
		private readonly ISisoDatabase _db;

		public DomainRepository(ISisoDatabase db)
		{
			_db = db;
		}

		public T Get<T>(Guid id) where T : AggregateRoot
		{
			using (var uow = _db.CreateQueryEngine())
			{
				return uow.GetById<T>(id);
			}
		}

		public IEnumerable<T> GetAll<T>() where T : AggregateRoot
		{
			using (var uow = _db.CreateQueryEngine())
			{
				return uow.GetAll<T>().ToList();
			}
		}

		public void Insert<T>(T aggregateRoot) where T : AggregateRoot
		{
			using (var uow = _db.CreateUnitOfWork())
			{
				uow.Insert(aggregateRoot);
				uow.Commit();
			}
		}

		public void Update<T>(T aggregateRoot) where T : AggregateRoot
		{
			using (var uow = _db.CreateUnitOfWork())
			{
				uow.Update(aggregateRoot);
				uow.Commit();
			}
		}

		public void Delete<T>(T aggregateRoot) where T : AggregateRoot
		{
			using (var uow = _db.CreateUnitOfWork())
			{
				uow.DeleteById<T>(aggregateRoot.Id);
				uow.Commit();
			}
		}
	}
}